# fvcore

## Recursive parameter counting
https://detectron2.readthedocs.io/en/latest/modules/fvcore.html#fvcore.nn.parameter_count

## Recompute BatchNorm population statistics
https://detectron2.readthedocs.io/en/latest/modules/fvcore.html#fvcore.nn.update_bn_stats

## A stateless, scale-invariant hyperparameter scheduler
https://detectron2.readthedocs.io/en/latest/modules/fvcore.html#fvcore.common.param_scheduler.ParamScheduler
